==> jaffm-1.2.1.tar.bz2: jaffm-1.2.1/settingswindow.cpp <==
#include "settingswindow.h"

enum
{
	BTN_OK = wxID_HIGHEST,
	BTN_CANCEL,
	TXT_DEFAULTAPP,
	TXT_SCREENMARGIN,
	BTN_SHOW_MENUBAR,
	BTN_SHOW_LOCATION,
	BTN_SHOW_TOOLBAR,
	BTN_AUTO_FIT_TREE,
	BTN_FILES,
	BTN_EXEC,
	BTN_FOLDERS,
};

BEGIN_EVENT_TABLE(SettingsWindow, wxFrame)
	EVT_BUTTON(BTN_OK, SettingsWindow::on_btnOK)
	EVT_BUTTON(BTN_CANCEL, SettingsWindow::on_btnCancel)
	EVT_CLOSE(SettingsWindow::on_this_close)
	EVT_TEXT(TXT_DEFAULTAPP, SettingsWindow::on_txtDefaultApp)
	EVT_TEXT(TXT_SCREENMARGIN, SettingsWindow::on_txtScreenMargin)
	EVT_CHECKBOX(BTN_SHOW_MENUBAR, SettingsWindow::on_btnShowMenubar)
	EVT_CHECKBOX(BTN_SHOW_LOCATION, SettingsWindow::on_btnShowLocation)
	EVT_CHECKBOX(BTN_SHOW_TOOLBAR, SettingsWindow::on_btnShowToolbar)
	EVT_CHECKBOX(BTN_AUTO_FIT_TREE, SettingsWindow::on_btnAutoFitTree)
	EVT_BUTTON(BTN_FILES, SettingsWindow::on_btnFiles)
	EVT_BUTTON(BTN_EXEC, SettingsWindow::on_btnExec)
	EVT_BUTTON(BTN_FOLDERS, SettingsWindow::on_btnFolders)
END_EVENT_TABLE()

SettingsWindow::SettingsWindow(wxFrame *oParent, const wxString &sTitle, Settings *oNewSettings)
: wxFrame(oParent, -1, sTitle, wxDefaultPosition, wxDefaultSize, wxDEFAULT_FRAME_STYLE)
{
	oPanel = new wxPanel(this, -1);
	oSettings = oNewSettings;
	
	// Sizer creation.
	oWindowSizer = new wxBoxSizer(wxVERTICAL);
	oMainSizer = new wxBoxSizer(wxVERTICAL);
	oFieldSizer = new wxFlexGridSizer(2, 2);
	oCloseSizer = new wxBoxSizer(wxHORIZONTAL);
	oGeneralRadioSizer = new wxBoxSizer(wxVERTICAL);
	oButtonSizer = new wxBoxSizer(wxHORIZONTAL);
	
	// Control creation.
	btnFiles = new wxButton(oPanel, BTN_FILES, "Files");
	btnExec = new wxButton(oPanel, BTN_EXEC, "Executables");
	btnFolders = new wxButton(oPanel, BTN_FOLDERS, "Folders");
	
	oFileSettingsPanel = new FileSettingsPanel(oPanel, oSettings);
	oExecSettingsPanel = new ExecSettingsPanel(oPanel, oSettings);
	
	lblDefaultApp = new wxStaticText(oPanel, -1, _("Default app: "));
	txtDefaultApp = new wxTextCtrl(oPanel, TXT_DEFAULTAPP, _(""));
	
	lblScreenMargin = new wxStaticText(oPanel, -1, _("Screen margin: "));
	txtScreenMargin = new wxTextCtrl(oPanel, TXT_SCREENMARGIN, _(""));
	
	btnShowMenubar = new wxCheckBox(oPanel, BTN_SHOW_MENUBAR, _("Show menubar"));
	btnShowLocation = new wxCheckBox(oPanel, BTN_SHOW_LOCATION, _("Show location bar"));
	btnShowToolbar = new wxCheckBox(oPanel, BTN_SHOW_TOOLBAR, _("Show toolbar"));
	btnAutoFitTree = new wxCheckBox(oPanel, BTN_AUTO_FIT_TREE, _("Automatically fit tree"));
	
	btnOK = new wxButton(oPanel, BTN_OK, _("OK"));
	btnCancel = new wxButton(oPanel, BTN_CANCEL, _("Cancel"));
	
	oGeneralBox = new wxStaticBox(oPanel, -1, _("General settings"));
	
	// Sizers that need to come into existence after something else is created.
	oGeneralSizer = new wxStaticBoxSizer(oGeneralBox, wxVERTICAL);
	
	// Sizer manipulation.
	oButtonSizer->Add(btnFiles);
	oButtonSizer->Add(btnExec, wxRIGHT, 4);
	oButtonSizer->Add(btnFolders, wxRIGHT, 4);
	
	oFieldSizer->Add(lblScreenMargin);
	oFieldSizer->Add(txtScreenMargin, 0, wxRIGHT, 4);
	oFieldSizer->Add(lblDefaultApp);
	oFieldSizer->Add(txtDefaultApp, 0, wxRIGHT, 4);
	
	oCloseSizer->Add(btnOK, 0, wxRIGHT, 4);
	oCloseSizer->Add(btnCancel);
	
	oGeneralRadioSizer->Add(btnShowMenubar);
	oGeneralRadioSizer->Add(btnShowLocation);
	oGeneralRadioSizer->Add(btnShowToolbar);
	oGeneralRadioSizer->Add(btnAutoFitTree);
	
	oGeneralSizer->Add(oFieldSizer, 0, wxALL, 4);
	oGeneralSizer->Add(oGeneralRadioSizer, 0, wxALL, 4);
	
	//oMainSizer->Add(oButtonSizer, 0, wxALL, 4);
	oMainSizer->Add(oGeneralSizer, 0, wxALL, 4);
	oMainSizer->Add(oCloseSizer, 0, wxALIGN_RIGHT | wxALL, 4);
	
	oWindowSizer->Add(oFileSettingsPanel, 0, wxGROW);
	oWindowSizer->Add(oExecSettingsPanel, 0, wxGROW);
	oWindowSizer->Add(oMainSizer, 0, wxGROW);
	
	// Formalities.
	setPanel(oFileSettingsPanel);
	oPanel->SetSizer(oWindowSizer);
	oPanel->SetAutoLayout(true);
	oWindowSizer->Fit(this);
	
	// And finally...
	readSettings();
}

void SettingsWindow::setPanel(wxWindow *oWindow)
{
	if (oWindow == oFileSettingsPanel)
	{
		oWindowSizer->Show(oFileSettingsPanel, true);
		oWindowSizer->Show(oExecSettingsPanel, false);
	}
	else if (oWindow == oExecSettingsPanel)
	{
		oWindowSizer->Show(oFileSettingsPanel, false);
		oWindowSizer->Show(oExecSettingsPanel, true);
	}

	oWindowSizer->Layout();
}

void SettingsWindow::on_btnOK(wxCommandEvent &oEvent)
{
	oSettings->save();
	Close();
}

void SettingsWindow::on_btnCancel(wxCommandEvent &oEvent)
{
	Close();
}

void SettingsWindow::on_this_close(wxCloseEvent &oEvent)
{
	oSettings->load();
	readSettings();
	Show(false);
}

void SettingsWindow::readSettings()
{
	txtDefaultApp->SetValue((wxChar *)oSettings->getGeneral("DEFAULT_APP").c_str());
	txtScreenMargin->SetValue((wxChar *)oSettings->getGeneral("SCREEN_MARGIN").c_str());
	
	btnShowMenubar->SetValue(oSettings->getGeneral("SHOW_MENUBAR") == "1");
	btnShowLocation->SetValue(oSettings->getGeneral("SHOW_LOCATION") == "1");
	btnShowToolbar->SetValue(oSettings->getGeneral("SHOW_TOOLBAR") == "1");
	btnAutoFitTree->SetValue(oSettings->getGeneral("AUTO_FIT_TREE") == "1");
}

void SettingsWindow::on_txtDefaultApp(wxCommandEvent &oEvent)
{
	oSettings->setGeneral("DEFAULT_APP", (char *)txtDefaultApp->GetValue().c_str());
}

void SettingsWindow::on_txtScreenMargin(wxCommandEvent &oEvent)
{
	oSettings->setGeneral("SCREEN_MARGIN", (char *)txtScreenMargin->GetValue().c_str());
}

void SettingsWindow::on_btnShowMenubar(wxCommandEvent &oEvent)
{
	oSettings->setGeneral("SHOW_MENUBAR", btnShowMenubar->GetValue() ? "1" : "0");
}

void SettingsWindow::on_btnShowLocation(wxCommandEvent &oEvent)
{
	oSettings->setGeneral("SHOW_LOCATION", btnShowLocation->GetValue() ? "1" : "0");
}

void SettingsWindow::on_btnShowToolbar(wxCommandEvent &oEvent)
{
	oSettings->setGeneral("SHOW_TOOLBAR", btnShowToolbar->GetValue() ? "1" : "0");
}

void SettingsWindow::on_btnAutoFitTree(wxCommandEvent &oEvent)
{
	oSettings->setGeneral("AUTO_FIT_TREE", btnAutoFitTree->GetValue() ? "1" : "0");
}

void SettingsWindow::on_btnFiles(wxCommandEvent &oEvent)
{
	setPanel(oFileSettingsPanel);
}

void SettingsWindow::on_btnExec(wxCommandEvent &oEvent)
{
	setPanel(oExecSettingsPanel);
}

void SettingsWindow::on_btnFolders(wxCommandEvent &oEvent)
{
}

==> jaffm-1.3.tar.bz2: jaffm-1.3/settingswindow.cpp <==
#include "settingswindow.h"

enum
{
	BTN_OK = wxID_HIGHEST,
	BTN_CANCEL,
	TXT_DEFAULTAPP,
	TXT_SCREENMARGIN,
	BTN_SHOW_MENUBAR,
	BTN_SHOW_LOCATION,
	BTN_SHOW_TOOLBAR,
	BTN_AUTO_FIT_TREE,
	BTN_FILES,
	BTN_EXEC,
	BTN_FOLDERS,
};

BEGIN_EVENT_TABLE(SettingsWindow, wxFrame)
	EVT_BUTTON(BTN_OK, SettingsWindow::on_btnOK)
	EVT_BUTTON(BTN_CANCEL, SettingsWindow::on_btnCancel)
	EVT_CLOSE(SettingsWindow::on_this_close)
	EVT_TEXT(TXT_DEFAULTAPP, SettingsWindow::on_txtDefaultApp)
	EVT_TEXT(TXT_SCREENMARGIN, SettingsWindow::on_txtScreenMargin)
	EVT_CHECKBOX(BTN_SHOW_MENUBAR, SettingsWindow::on_btnShowMenubar)
	EVT_CHECKBOX(BTN_SHOW_LOCATION, SettingsWindow::on_btnShowLocation)
	EVT_CHECKBOX(BTN_SHOW_TOOLBAR, SettingsWindow::on_btnShowToolbar)
	EVT_CHECKBOX(BTN_AUTO_FIT_TREE, SettingsWindow::on_btnAutoFitTree)
	EVT_BUTTON(BTN_FILES, SettingsWindow::on_btnFiles)
	EVT_BUTTON(BTN_EXEC, SettingsWindow::on_btnExec)
	EVT_BUTTON(BTN_FOLDERS, SettingsWindow::on_btnFolders)
END_EVENT_TABLE()

SettingsWindow::SettingsWindow(wxFrame *oParent, const wxString &sTitle, Settings *oNewSettings)
: wxFrame(oParent, -1, sTitle, wxDefaultPosition, wxDefaultSize, wxDEFAULT_FRAME_STYLE)
{
	oPanel = new wxPanel(this, -1);
	oSettings = oNewSettings;
	
	// Sizer creation.
	oWindowSizer = new wxBoxSizer(wxVERTICAL);
	oMainSizer = new wxBoxSizer(wxVERTICAL);
	oFieldSizer = new wxFlexGridSizer(2, 2);
	oCloseSizer = new wxBoxSizer(wxHORIZONTAL);
	oGeneralRadioSizer = new wxBoxSizer(wxVERTICAL);
	oButtonSizer = new wxBoxSizer(wxHORIZONTAL);
	
	// Control creation.
	btnFiles = new wxButton(oPanel, BTN_FILES, wxT("Files"));
	btnExec = new wxButton(oPanel, BTN_EXEC, wxT("Executables"));
	btnFolders = new wxButton(oPanel, BTN_FOLDERS, wxT("Folders"));
	
	oFileSettingsPanel = new FileSettingsPanel(oPanel, oSettings);
	oExecSettingsPanel = new ExecSettingsPanel(oPanel, oSettings);
	
	lblDefaultApp = new wxStaticText(oPanel, -1, _("Default app: "));
	txtDefaultApp = new wxTextCtrl(oPanel, TXT_DEFAULTAPP, _(""));
	
	lblScreenMargin = new wxStaticText(oPanel, -1, _("Screen margin: "));
	txtScreenMargin = new wxTextCtrl(oPanel, TXT_SCREENMARGIN, _(""));
	
	btnShowMenubar = new wxCheckBox(oPanel, BTN_SHOW_MENUBAR, _("Show menubar"));
	btnShowLocation = new wxCheckBox(oPanel, BTN_SHOW_LOCATION, _("Show location bar"));
	btnShowToolbar = new wxCheckBox(oPanel, BTN_SHOW_TOOLBAR, _("Show toolbar"));
	btnAutoFitTree = new wxCheckBox(oPanel, BTN_AUTO_FIT_TREE, _("Automatically fit tree"));
	
	btnOK = new wxButton(oPanel, BTN_OK, _("OK"));
	btnCancel = new wxButton(oPanel, BTN_CANCEL, _("Cancel"));
	
	oGeneralBox = new wxStaticBox(oPanel, -1, _("General settings"));
	
	// Sizers that need to come into existence after something else is created.
	oGeneralSizer = new wxStaticBoxSizer(oGeneralBox, wxVERTICAL);
	
	// Sizer manipulation.
	oButtonSizer->Add(btnFiles);
	oButtonSizer->Add(btnExec, wxRIGHT, 4);
	oButtonSizer->Add(btnFolders, wxRIGHT, 4);
	
	oFieldSizer->Add(lblScreenMargin);
	oFieldSizer->Add(txtScreenMargin, 0, wxRIGHT, 4);
	oFieldSizer->Add(lblDefaultApp);
	oFieldSizer->Add(txtDefaultApp, 0, wxRIGHT, 4);
	
	oCloseSizer->Add(btnOK, 0, wxRIGHT, 4);
	oCloseSizer->Add(btnCancel);
	
	oGeneralRadioSizer->Add(btnShowMenubar);
	oGeneralRadioSizer->Add(btnShowLocation);
	oGeneralRadioSizer->Add(btnShowToolbar);
	oGeneralRadioSizer->Add(btnAutoFitTree);
	
	oGeneralSizer->Add(oFieldSizer, 0, wxALL, 4);
	oGeneralSizer->Add(oGeneralRadioSizer, 0, wxALL, 4);
	
	//oMainSizer->Add(oButtonSizer, 0, wxALL, 4);
	oMainSizer->Add(oGeneralSizer, 0, wxALL, 4);
	oMainSizer->Add(oCloseSizer, 0, wxALIGN_RIGHT | wxALL, 4);
	
	oWindowSizer->Add(oFileSettingsPanel, 0, wxGROW);
	oWindowSizer->Add(oExecSettingsPanel, 0, wxGROW);
	oWindowSizer->Add(oMainSizer, 0, wxGROW);
	
	// Formalities.
	setPanel(oFileSettingsPanel);
	oPanel->SetSizer(oWindowSizer);
	oPanel->SetAutoLayout(true);
	oWindowSizer->Fit(this);
	
	// And finally...
	readSettings();
}

void SettingsWindow::setPanel(wxWindow *oWindow)
{
	if (oWindow == oFileSettingsPanel)
	{
		oWindowSizer->Show(oFileSettingsPanel, true);
		oWindowSizer->Show(oExecSettingsPanel, false);
	}
	else if (oWindow == oExecSettingsPanel)
	{
		oWindowSizer->Show(oFileSettingsPanel, false);
		oWindowSizer->Show(oExecSettingsPanel, true);
	}

	oWindowSizer->Layout();
}

void SettingsWindow::on_btnOK(wxCommandEvent &oEvent)
{
	oSettings->save();
	Close();
}

void SettingsWindow::on_btnCancel(wxCommandEvent &oEvent)
{
	Close();
}

void SettingsWindow::on_this_close(wxCloseEvent &oEvent)
{
	oSettings->load();
	readSettings();
	Show(false);
}

void SettingsWindow::readSettings()
{
	txtDefaultApp->SetValue((wxChar *)oSettings->getGeneral("DEFAULT_APP").c_str());
	txtScreenMargin->SetValue((wxChar *)oSettings->getGeneral("SCREEN_MARGIN").c_str());
	
	btnShowMenubar->SetValue(oSettings->getGeneral("SHOW_MENUBAR") == "1");
	btnShowLocation->SetValue(oSettings->getGeneral("SHOW_LOCATION") == "1");
	btnShowToolbar->SetValue(oSettings->getGeneral("SHOW_TOOLBAR") == "1");
	btnAutoFitTree->SetValue(oSettings->getGeneral("AUTO_FIT_TREE") == "1");
}

void SettingsWindow::on_txtDefaultApp(wxCommandEvent &oEvent)
{
	oSettings->setGeneral("DEFAULT_APP", (char *)txtDefaultApp->GetValue().c_str());
}

void SettingsWindow::on_txtScreenMargin(wxCommandEvent &oEvent)
{
	oSettings->setGeneral("SCREEN_MARGIN", (char *)txtScreenMargin->GetValue().c_str());
}

void SettingsWindow::on_btnShowMenubar(wxCommandEvent &oEvent)
{
	oSettings->setGeneral("SHOW_MENUBAR", btnShowMenubar->GetValue() ? "1" : "0");
}

void SettingsWindow::on_btnShowLocation(wxCommandEvent &oEvent)
{
	oSettings->setGeneral("SHOW_LOCATION", btnShowLocation->GetValue() ? "1" : "0");
}

void SettingsWindow::on_btnShowToolbar(wxCommandEvent &oEvent)
{
	oSettings->setGeneral("SHOW_TOOLBAR", btnShowToolbar->GetValue() ? "1" : "0");
}

void SettingsWindow::on_btnAutoFitTree(wxCommandEvent &oEvent)
{
	oSettings->setGeneral("AUTO_FIT_TREE", btnAutoFitTree->GetValue() ? "1" : "0");
}

void SettingsWindow::on_btnFiles(wxCommandEvent &oEvent)
{
	setPanel(oFileSettingsPanel);
}

void SettingsWindow::on_btnExec(wxCommandEvent &oEvent)
{
	setPanel(oExecSettingsPanel);
}

void SettingsWindow::on_btnFolders(wxCommandEvent &oEvent)
{
}
